#
# spec file for package libfilezilla
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define major		43
%define libname		%{name}%{major}
%define develname	%{name}-devel
Name:           libfilezilla
Version:        0.47.0
Release:        1.1
Summary:        C++ library for filezilla
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://lib.filezilla-project.org/
Source0:        https://download.filezilla-project.org/libfilezilla/%{name}-%{version}.tar.xz
Patch0:         %{name}-date-time.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  fdupes
%if 0%{?suse_version} > 1500
BuildRequires:  gcc-c++
%else
BuildRequires:  gcc8-c++
%endif
BuildRequires:  graphviz
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cppunit)
BuildRequires:  pkgconfig(gmp)
BuildRequires:  pkgconfig(gnutls) >= 3.7.0
BuildRequires:  pkgconfig(hogweed) >= 3.1
BuildRequires:  pkgconfig(nettle) >= 3.1
Recommends:     %{name}-lang

%description
libfilezilla is C++ library, offering some basic functionality to
build high-performing, platform-independent programs. libfilezilla is
needed for filezilla (an FTP client and server) to build.

%package -n	%{libname}
Summary:        C++ library for filezilla
# Provide basename, required for the (unversioned) -lang package.
Group:          System/Libraries
Provides:       %{name} = %{version}

%description -n	%{libname}
libfilezilla is C++ library, offering some basic functionality to
build high-performing, platform-independent programs. libfilezilla is
needed for filezilla (an FTP client and server) to build. Some of the
highlights include:

* A typesafe, multi-threaded event system.
* Timers for periodic events.
* A datetime class that not only tracks timestamp but also their accuracy,
  which simplifies dealing with timestamps originating from different sources.
* Simple process handling for spawning child processes with redirected I/O.

%package -n	%{develname}
Summary:        Development package for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}-%{release}

%description -n	%{develname}
Files needed for development with %{name}.





# Need %%lang_package expanded for an extra conflict with an old library package
%package lang
# FIXME: consider using %%lang_package macro
Summary:        Translations for package %{name}
# in libfilezilla 0.18.x, we wrongly shipped the languages files directly in the library package
Group:          System/Localization
Requires:       %{name} = %{version}
Conflicts:      libfilezilla0 < 0.19
Provides:       %{name}-lang-all = %{version}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup -p1

%build
%if 0%{?suse_version} <= 1500
export CC="%{_bindir}/gcc-8"
export CXX="%{_bindir}/g++-8"
%endif
autoreconf -fi
%configure --disable-static
%make_build

pushd doc
%make_build html
popd

%install
%make_install
# we don't want this
find %{buildroot} -type f -name "*.la" -delete -print
mkdir -p %{buildroot}%{_docdir}/%{develname}
cp -r doc/doxygen-doc/* %{buildroot}%{_docdir}/%{develname}/
rm -f %{buildroot}%{_docdir}/%{develname}/latex/refman.tex
%fdupes -s %{buildroot}%{_docdir}/%{develname}
%find_lang %{name}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_libdir}/%{name}.so.%{major}*

%files lang -f %{name}.lang

%files -n %{develname}
%dir %{_docdir}/%{develname}
%{_docdir}/%{develname}/*
%{_includedir}/%{name}/
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Tue Apr 16 2024 ecsos <ecsos@opensuse.org>
- Update to 0.47.0
  * New features:
  - PKCS#11 support, provided GnuTLS has been compiled with
    PKCS#11 support enabled
  * Bugfixes and minor changes:
  - Added parameter to fz::remove_dir that allows returning an
    error if the directory did not exist
  - Add logging of aio reader/writers cannot be opened, fix return
    value of reader when trying to read nothing
  - HTTP: Delay sending subsequent requests after having
    received a response with "Connection: close" set
  - Listen sockets are now created with the SO_REUSEADDR
    (SO_EXCLUSIVEADDRUSE on Windows) flag set
  - Added cert_type::codesign as key purpose to certificate
    request and creation functions in fz::tls_layer
- Drop libfilezilla-fix-crash.patch, becuase now in upstream
* Wed Mar 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add libfilezilla-fix-crash.patch: Fix crash when uploading files
  (boo#1219800).
* Mon Feb 26 2024 ecsos <ecsos@opensuse.org>
- Adjustments patch macro for rpm 4.20.
* Thu Feb  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.46.0:
  + fz::process: Add io redirection mode that excluded stderr.
  + fz::remove_file and remove_dir now take additional parameter
    and return fz::result.
  + Added transitional fz::file::read2 and fz::file::write2
    returning fz::rwresult, old read/write have been marked
    deprecated.
  + HTTP: Fix redirect if "Connection: close" header is set.
- Bump major to 42, following upstream sover bump.
* Tue Oct 24 2023 ecsos <ecsos@opensuse.org>
- Update to 0.45.0
  * New features:
  - fz::hash_accumulator now also works with hmac_sha256
  - Added is_digest and digest_size to fz::hash_acumulator
  - MSW: Added function to delete registry values
  * Bugfixes and minor changes:
  - Fixed a crash and a stall in the HTTP client
* Wed Jul 12 2023 ecsos <ecsos@opensuse.org>
- Update to 0.44.0
  * New features:
  - Exportable hash accumulator state
  - Add for RSA key support for JWS
  - JWT creation
  - Conversion functions from X.509 private keys to JWK
  * Bugfixes and minor changes:
  - Added logging when certificate is untrusted by system trust store
- Changes from 0.43.0
  * New features:
  - Added fz::tls_layer::generate_cert_from_csr
  * Bugfixes and minor changes:
  - fz::event_loop performance improvements when timers are in use
* Sat Jun  3 2023 ecsos <ecsos@opensuse.org>
- Update to 0.42.2
  * Bugfixes and minor changes:
  - Further HTTP client fixes
- Changes from 0.42.1
  * Bugfixes and minor changes:
  - Small HTTP client improvements to force IPv4/IPv6 for new
    connections, add a header count limit, and to make abuffer
    pool optional
- Changes from 0.42.0
  * New features:
  - Added an HTTP client
  * Bugfixes and minor changes:
  - Sources are now distributed in a .tar.xz
  - buffer_writer now clears the buffer when opened
  - Fixes and performance improvements for fz::xml::parser
  - *nix: fz::file::size() now returns -1 on character devices
* Fri Feb 24 2023 ecsos <ecsos@opensuse.org>
- Update to 0.41.1
  * Bugfixes and minor changes:
  - Fixed a crash signalling aio waiters
  - Added listen_socket::from_descriptor
* Wed Jan 25 2023 ecsos <ecsos@opensuse.org>
- Update to 0.41.0
  * New features:
  - Added fz::xml::parser and fz::xml::namespace_parser
  - Added fz::is_valid_utf8
  - Added fz::utf16le_to_utf8_append and fz::utf16be_to_utf8_append
- Changes from 0.40.0
  * New features:
  - Added fz::unicode_codepoint_to_utf8_append
  - Added fz::strtokenizer
  - Added fz::check_certificate_status
* Fri Nov 18 2022 ecsos <ecsos@opensuse.org>
- Update to 0.39.2
  * Bugfixes and minor changes:
  - Fixed removing aio_waiters/event_handlers from aio_waitable
  - Fixed start offset in view_reader
  - Fix buffer_writer not releasing added buffers
* Sat Sep 24 2022 ecsos <ecsos@opensuse.org>
- Update to 0.39.1
  * Bugfixes and minor changes:
  - MSW: Fixed a possible hang in fz::process:kill
- Changes from 0.39.0
  * New features:
  - Added readwrite mode to fz::file.
  - MSW: Added fz::dll and fz::shdlls glue
  - Added fz::ascii_layer
  * Bugfixes and minor changes:
  - *nix: Fixed mmap error handling in fz::aio_buffer_pool
  - Fixed a potential deadlock in the aio code
  - Fixed an issue with calling conventions on 32bit Windows
  - MSW: fz::datetime::get_tm now works for dates past Y2K38 on
    toolchains with 32bit time_t
  - MSW: Fixed an error reading from fz::process
* Sat Jul 23 2022 ecsos <ecsos@opensuse.org>
- Update to 0.38.1
  * New features:
  - fz::aio_waitable now also accepts event handlers in addition
    to aio_waiter
  * Bugfixes and minor changes:
  - Split fz::process::kill into separate stop and kill functions
- Changes from 0.38.0
  * New features:
  - Added readers and writers for asynchronous disk I/O operating
    on a buffer pool
  - Added fz::current_username()
  - Added fz::event_handler::stop_add_timer
  - Added overload for fz::event_handler::add_timer that takes
    a deadline
  - Added fz::file::set_modification_time
  - Added fz::get_network_interfaces
  - *nix: fz::socket can now accept Unix-domain sockets,
    added fz::socket::send_fd and fz::socke::read_fd
  * Bugfixes and minor changes:
  - *nix: When impersonating, limit supplementary groups to
    NGROUPS_MAX
* Thu May 12 2022 ecsos <ecsos@opensuse.org>
- Update to 0.37.2
  * New features:
  - Added a null_logger that doesn't do anything
  * Bugfixes and minor changes:
  - MSW: fz::mkdir with restricted permissions now uses
    inheritable ACLs
  - MSW: Minor performance improvements reading from fz::process
    and explicit cancellation of pending I/O when killing child
    processes.
* Fri Apr  8 2022 ecsos <ecsos@opensuse.org>
- Update to 0.37.1
  * New features:
  - Added convenience functions ot fz::json
  * Bugfixes and minor changes:
  - MSW: Fixed spawning fz::process with blocking communication
- Changes from 0.37.0
  * New features:
  - *nix: password-less impersonation can take an optional group
  - Added demo https client showcasing usage of fz::socket and
    fz::tls_layer
  - Added some compile-time checks for fz::sprintf arguments
  - MSW: Added fz::registry
  - Added a way to use non-blocking read/write with fz::process
  * Bugfixes and minor changes:
  - Added fz::logger_interface::log_u which assumes string
    arguments are in UTF-8 as opposed to the character set used
    by the current locale
  - Disallow spawning additional threads while fz::thread_pool is
    in the process of being destroyed
  - *nix: poll() is now mandatory, the select() based socket
    event loop has been removed
  - Simplified fz::socket implementation through use of internal
    fz::poller
- Changes from 0.36.0
  * New features:
  - Added parameter to tls_layer::set_alpn to control which peer
    has priority over which ALPN is chosen.
  - Added fz::hmac_sha1
  - Mutex debugging framework to detect locking order inversions
    that may lead to deadlocks
  - Add additional io_redirect mode to fz::process_spawn where
    the parent-side handles for stdin/out/err are always closed
  * Bugfixes and minor changes:
  - fz::json: Handle object members with empty string as name
  - Minor performance improvements to removing timers and to
    spawning processes
* Sun Dec 12 2021 ecsos <ecsos@opensuse.org>
- Update to 0.35.0
  * New features:
  - *nix: Added fz::forkblock which can be used to safely set
    FD_CLOEXEC on descriptors even if the system lacks
    SOCK_CLOCKEXEC, MSG_CMSG_CLOEXEC, pipe2 or accept4
  - macOS: Impersonation support
  - Added fz::tls_layer::set_unexpected_eof_cb, in some
    situations it may be desirable that unexpected closure is not
    reported as a hard errror
  * Bugfixes and minor changes:
  - Added various convenience overloads for fz::buffer
  - Performance improvement for fz::json::to_string
* Sat Nov  6 2021 ecsos <ecsos@opensuse.org>
- Update to 0.34.2
  * New features:
  - fz::file::open now returns fz::result
  * Bugfixes and minor changes:
  - fz::tls_layer: Additional fixes for trust path extration
  - MSW: fz::local_filesys::get_next_file now handles directory
    contents returned by the kernel in oversized buffers with
    embedded nulls
- Changes from 0.34.1
  * Bugfixes and minor changes:
  - *nix: Handle supplementary groups when impersonating
  - *nix: fz::recv_fd now sets the MSG_CMSG_CLOEXEC flag
  - *nix: fz::local_filesys::get_link_target now handles link
    targets larger than 1024 bytes
  - MSW: Restrict DLL search path for system DLLs to the system32
    directory
  - fz::tls_layer: Fixed how trust path extration interacts with
    CRLs
- Changes from 0.34.0
  * Bugfixes and minor changes:
  - MSW: Load shell32.dll and ole32.dll on-demand at runtime,
    it is not available in all environments
  - Made fz::local_filesys movable
* Thu Aug 12 2021 ecsos <ecsos@opensuse.org>
- Update to 0.31.1
  * New features:
  - Added iterator for JSON arrays
  * Bugfixes and minor changes:
  - *nix: SIGPIPE is now set to SIG_IGN the first time a pipe or
    socket gets created
  - Handle empty search string in replace_subscripts
- Changes from 0.31.0
  * New features:
  - Added simple JSON parser
  - Added basic JWS generator
  * Bugfixes and minor changes:
  - Made fz::file movable
  - Fixed empty creation_flag for fz::file if other flags are
    also passed
- Changes from 0.30.0
  * New features:
  - Added a flag to fz::file::creation_flags to create files with
    permissions only granting the current user and administrators
    access
  - Added mkdir_permissions flags to fz::mkdir
* Mon Jul  5 2021 ecsos <ecsos@opensuse.org>
- Update to 0.29.0
  * New features:
  - Added fz::tls_layer::set_min_tls_ver and for testing purposes
    set_max_tls_ver
  - The TLS layer now also supports server-side session
    resumption with TLS <= 1.2 clients not supporting session
    tickets
  - Added fz::rename_file
  - MSW: Added libfilezilla/glue/windows.hpp to set proper
    defines before including windows.h
  - Added fz::move_assign_through_move_constructor for classes
    that depend on normal destruction order even on move
    assignment
  * Bugfixes and minor changes:
  - Fixed memory leak in fz::tls_layer::set_alpn
  - IPv6 listen sockets are now always created with IPV6_V6ONLY
    to unify behavior across platforms
  - Fixes for issues found by --socketdebug
  - Fixed warnings when bool arguments are passed to fz::sprintf
  - Fixed warnings in fz::to_integral<bool>
* Fri May  7 2021 ecsos <ecsos@opensuse.org>
- Update to 0.28.0
  * New features:
  - Added fz::hostname_lookup
  - Added fz::datetime::set_rfc3339
  - Added fz::load_certificates and fz::load_certificates_file
  - Added fz::base64_encode_append
  * Bugfixes and minor changes:
  - Moved some common functionality shared by multiple layers to
    socket_layer itself
  - Fixed a crash with older versions of GnuTLS if the system
    trust store cannot be loaded
* Sat Mar 20 2021 ecsos <ecsos@opensuse.org>
- Update to 0.27.1
  * Bugfixes and minor changes:
  - Fixed a socket event sequencing invariant violation in
    tls_layer
  - Fixed query_string constructor leaving object in undefined
    state if set fails
  - Fixed arguments passed from the templated equal_constime
    helper
* Thu Mar 11 2021 ecsos <ecsos@opensuse.org>
- Update to 0.27.0
  * New features:
  - Added fz::normalize_hypens to replace all hyphen-like
    characters in a string with the good old hyphen-minus
  - Added fz::pbkdf2_hmac_sha256
  - Added visibility_helper.hpp to simplify exporting symbols in
    shared libraries
  - Added fz::compound_rate_limited_layer to which multiple rate
    limiters can be dynamically added/removed
  - Added redirect_io parameter to fz::process::spawn
  - Added --enable-socketdebug configure argument to check for
    invariant violation when handling socket events
  - Added a optional preamble to server_handshake that is sent
    after initializing the session, but before the SERVER_HELLO
  * Bugfixes and minor changes:
  - Various fixes to socket event retriggering if
    socket_interface::set_event_handler is used
  - Fixed a nullpointer dereference in fz::tls_layer if a
    hostname is set prior to creating a session
* Mon Jan  4 2021 ecsos <ecsos@opensuse.org>
- Update to 0.26.0
  * New features:
  - Added fz::buffer::capacity()
  - fz::buffer::append now also accepts single characters
    and std::vector
  - Added fz::nonowning_buffer
  - MSW: Added fz::process::handle()
  - *nix: Allow passing extra file descriptors to child processes
  - fz::to_wstring_from_utf8 now accepts std::string_view
    and fz::buffer
  - fz::replace_substrings and fz::replaced_substrings now accept
    string views and single characters
  * Bugfixes and minor changes:
  - Reset bucket data if it gets removed from a rate_limiter
* Wed Oct 21 2020 ecsos <ecsos@opensuse.org>
- Update to 0.25.0
  * New features:
  - Added fz::invoker to asynchronously call functions to run in
    a specific thread independent of the caller's thread
  * Bugfixes and minor changes:
  - Added additional checks to fz::buffer to leave the buffer in
    a valid state in out-of-memory situations and to prevent
    mis-use
  - Detect a particular socket buffer tuning issue under Linux
    where setting a receiver buffer size shrinks the window scale
    factor
  - Reordered a few data members to reduce the amount of
    structure padding due to alignment
* Mon Sep  7 2020 ecsos <ecsos@opensuse.org>
- Update to 0.24.1
  * Bugfixes and minor changes:
  - fz::to_integral can now handle strongly typed enum return types
* Sat Aug 22 2020 ecsos <ecsos@opensuse.org>
- Update to 0.24.0
  * New features:
  - Added fz::equal_consttime
  * Bugfixes and minor changes:
  - fz::sprintf now works corrcetly if arguments are passed as
    (w)string_view
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.23.0:
  + Added reader/writer locks
  - fz::mkdir can now return the the longest created path in case of partial failures
* Wed May 13 2020 ecsos <ecsos@opensuse.org>
- Update to 0.22.0
  * New features:
  - Added a flag to fz::file to allow creation of files with
    permissions only granting the current user access
  - Added fz::mkdir to create local directories, optionally
    recursive and with permissions to only grant the current
    user access to the final directory
  * Bugfixes and minor changes:
  - MSW: Improvements handling directory reparse points
  - Lengthen partial certificate chains in fz::tls_info to
    include any found trust anchor if using the system trust store
  - Mark self-signed certificates in the in fz::x509_certificate
  - Fix constructing fz::uri from default-constructed string_view
- Changes from 0.21.0
  * New features:
  - macOS: fz::spawn_detached_process can now start application
    bundles
  - Changed arguments of fz::local_filesys::get_next_file to be
    consistent with fz::local_filesys::get_file_info
  * Bugfixes and minor changes:
  - Improved error detection for fz::spawn_detached-process on
  * nix systems that support the pipe2 syscall with O_CLOEXEC
* Thu Mar 12 2020 ecsos@opensuse.org
- Update to 0.20.2
  * New features:
  - Add encrypt_key and decrypt_key to fz::symmetric key
  * Bugfixes and minor changes:
  - fz::datetime::set_rfc822 now parses the zone offset
  - Removed unneeded asserts from format.hpp
- Changes from 0.20.1
  * Bugfixes and minor changes:
  - Fix potential crash after removing the last speed limit
    bucket
  - TLS: Fix reported key exchange algorithm and improve details
- Changes from 0.20.0
  * New features:
  - Added fz::symmetric_key
  - Added itertions parameter to fz::private_key::from_password
  - Added fz::base32_encode and fz::base32_decode
  - Unified all decode functions to always return a vector, added
    alternatives returning string with a _s suffix in the
    function name
  - Changed equal_insensitive_ascii to take (w)string_view
* Fri Feb  7 2020 ecsos@opensuse.org
- Update to 0.19.3
  * Bugfixes and minor changes:
  - Rate limiting: Fix a divide by zero when distributing
    overflow
- Changes from 0.19.2
  * New features:
  - Rate limiting: Added debt repay mechanism to bucket removal
  * Bugfixes and minor changes:
  - *nix: Fix returned permissions in
    fz::local_filesys::get_file_info/get_next_file
- Run spec-cleaner.
* Sat Nov 30 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Split language files properly out into libfilezille-lang in order
  to avoid file conflicts between multiple versions of the library.
* Tue Nov 26 2019 ecsos@opensuse.org
- Update to 0.19.1
  * New features:
  - Return error information to
    fz::local_filesys::begin_find_files
  * Bugfixes and minor changes:
  - Fix for version.hpp not getting installed
- Changes from 0.19.0
  * New features:
  - Addded rate limiting code and a new rate-limited socket layer
  - Added fz::mutex::try_lock
  - Implemented libtool's library versioning scheme for shared
    library builds of libfilezilla
* Mon Nov  4 2019 ecsos@opensuse.org
- Update to 0.18.2
  * New features:
  - Added operator== and != to fz::uri
* Sun Aug 25 2019 ecsos@opensuse.org
- Update to 0.18.1
  * New features:
  - Added fz::buffer::resize
- Changes from 0.18.0
  * New features:
  - Added fz::spawn_detached_process
  - Add operator+ to fz::duration
  - *nix: If available, use eventfd instead of a self-pipe
  - fz::to_integral and fz::hex_decode now work with string
    literals
  - Added fz::listen_socket::fast_accept that only returns
    a descriptor instead of a fully-initialized fz::socket for
    use in a tight accept-and-dispatch loop
  - Functions in libfilezilla/iputils.hpp now take string_view as
    arguments
  - Added fz::socket::set_flags which can atomically enable or
    disable flags
  * Bugfixes and minor changes:
  - fz::socket not returns an error instead of silently failing
    in case of file descriptor exhaustion
  - Fix socket errors sometimes not being forwarded in
    fz::tls_layer when when writing fails in the underlying layer
  - Fix double-closing of socket descriptios if connection
    establishment fails
  - fz::tls_layer now fails the handshake instead of waiting
    indefinitely if started on a layer that has progressed passed
    the connected state
  - Small compile-time improvements to fz::sprintf
* Sat Jun 29 2019 ecsos@opensuse.org
- Update to 0.17.1
  * New features:
  - Added support for detached signatures
  * Bugfixes and minor changes:
  - Fixed crash if using the system trust store
- Changes from 0.17.0
  * New features:
  - libfilezilla now requires C++17
  - Changed a lot of functions to use std::string_view
  - Added fz::socket_layer as base class for layers on top of
    sockets
  - Added fz::tls_layer, a Transport Layer Security layer,
    requiring GnuTLS 3.5.7 or later
  - Added fz::translate for gettext-style translatable strings.
    GNU Gettext is now a built-time (but not runtime) dependency
  - Added fz::bitscan and fz::bitscan_reverse to get the index of
    least and most significant bit set
  - Added fz::logger_interface as a base for logging system
  * Bugfixes and minor changes:
  - *nix: Small speed-up of fz::local_filesys through the use of
    fstatat()
* Wed May 15 2019 ecsos@opensuse.org
- Run spec-cleaner.
* Thu May  9 2019 Michael Ströder <michael@stroeder.com>
- Update to 0.16.0
  * New features:
  - Add fz::socket
  - Add operator*= to fz::duration
  - fz::event_loop can now also be created using fz::thread_pool
    or threadless.
  * Bugfixes and minor changes:
  - fz::async_task now releases the thread back to the pool
    immediately when the task has completed without waiting for
    the join
  - *nix: Fix file descriptor leaks on exec()
* Sat Dec  1 2018 ecsos@opensuse.org
- Update to 0.15.1
  * New features:
  - Add argument to fz::strtok to return empty tokens
  * Bugfixes and minor changes:
  - Fix compatibility issue with Nettle < 3.3
  - Fix fz::random_bytes on MinGW
  - Fix memory leak in fz::buffer
* Sat Oct 27 2018 ecsos@opensuse.org
- update to 0.15.0
  * New features:
  - libfilezilla now depends on Nettle >= 3.1
  - Added fz::sha512, fz::sha256, fz::sha1 and fz::md5 hash
    functions
  - Added fz::hash_accumulator
  - Added fz::hmac_sha256 HMAC function
  - Added asymmetric encryption scheme using X25519
  - Added signature scheme using Ed25519
  * Bugfixes and minor changes:
  - Changed and documented semantics of the return value of
    fz::remove_file, removing a non-existing file is not an error
- Drop extra COPYING file and use it from upstream
* Sat Oct 13 2018 ecsos@opensuse.org
- update to 0.14.0
  * New features:
  - Added fz::equal_insensitive_ascii
  - Added insensitive_ascii parameter to fz::starts_with
    and fz::ends_with
  * Bugfixes and minor changes:
  - Fixed namespace of to_wstring in wx glue
* Mon Sep 24 2018 ecsos@opensuse.org
- update to 0.13.2
  * Bugfixes and minor changes:
  - Fix regression in fz::shared_value::clear
  - Fix parsing of URIs without path
- changes from 0.13.1
  * New features:
  - Made fz::scoped_lock movable
  * Bugfixes and minor changes:
  - Fix a few compiler warnings
* Mon Aug  6 2018 ecsos@opensuse.org
- update to 0.13.0
  * New features:
  - Add bool return value to replace_substrings to indicate
    whether something has been replaced.
  - fz::sprintf: Added %%c format specifier
  * Bugfixes and minor changes:
  - MSW: Work around problematic DLL export of templates,
    timers now work if libfilezilla has been built as DLL
* Tue Jun 19 2018 ecsos@opensuse.org
- update to 0.12.3
  * New features:
  - Event handlers can now removed themselves while inside
    a callback
  - Added fz::query_string::pairs()
* Tue May  8 2018 ecsos@opensuse.org
- update to 0.12.2
  * New features:
  - Added parameters to base64_encode to control alphabet and
    padding
  - Improved performance of less_insensitive_ascii
  - *nix: Faster conversion between UTF-8 and wchar_t strings.
* Sat Feb 24 2018 ecsos@opensuse.org
- update to 0.12.1
  * New features:
  - Added fz::buffer::operator== and operator!=
  * Bugfixes and minor changes:
  - Fixed bug in fz::buffer::get(size_t)
- changes from 0.12.0
  * New features:
  - Added fz::datetime::operator bool
  - Added fz::datetime::get_rfc822 and fz::datetime::set_rfc822
* Thu Jan 25 2018 ecsos@opensuse.org
- update to 0.11.2
  * New features:
  - Added fz::starts_with and fz::ends_with
* Sun Nov 12 2017 ecsos@opensuse.org
- update to 0.11.1
  * New features:
  - Added fz::file::fsync() to sync data to disk
* Mon Oct  2 2017 ecsos@opensuse.org
- update to 0.11.0
  * New features:
  - Add fz::buffer class
  * Bugfixes and minor changes:
  - *nix: fz::process::spawn no longer calls async-signal-unsafe
    functions between forking and calling execv in the child.
* Fri Aug 25 2017 jengelh@inai.de
- RPM group fixes. Trim descriptions and make it more neutral.
* Sun Aug 20 2017 ecsos@opensuse.org
- update to 0.10.1
  * Bugfixes and minor changes:
  - MSW: Improve handling of reparse points in fz::local_filesys
* Sat Aug  5 2017 ecsos@opensuse.org
- update to 0.10.0
  * New features:
  - Added fz::percent_encode and fz::percent_encode
  - Added fz::uri and fz::query_string
  - Added fz::less_insensitive_ascii for case-insensitive strings
    in maps
  * Bugfixes and minor changes:
  - Moved encoding functions from string.hpp to encode.hpp
  - Use pkg-config instead of cppunit-config to look for cppunit.
- remove patch libfilezilla-fix_undefined_reference.patch because
  now in upstream
* Sun Jun  4 2017 ecsos@opensuse.org
- update to 0.9.2
  * New features:
  - Added fz::random_bytes to obtain a vector of the passed size
    of uniformly distributed random bytes
  - Added fz::ltrim and fz::rtim
  - Added parameter to trim functions which characters to trim
  - It is now possible to detach threads from async_task
- add patch libfilezilla-fix_undefined_reference.patch to prevent
  build error in filezilla
* Thu Feb 23 2017 ecsos@opensuse.org
- update to 0.9.1
  * New features:
  - Added a small helper function to fz::file to get the current
    position in the file
  - Added another version of fz::to_wstring_from_utf8 that takes
    a char buffer + length
  * Bugfixes and minor changes:
  - Fixed extraction of single-character tokens in fz::strtok
* Tue Dec  6 2016 ecsos@opensuse.org
- update to 0.9.0
  * New features:
  - Added parameter to fz::to_integral to specify which value is
    returned on error.
  - Added fz::remove_file
  - Added fz::hex_encode and fz::hex_decode
* Sun Nov 20 2016 ecsos@opensuse.org
- update to 0.8.0
  * New features:
  - Added fz::str_toupper_ascii to complement
    fz::str_tolower_ascii
  - Added fz::trim and fz::trimmed for removing leading and
    trailing whitespace from string
  - Added fz::str_is_ascii
  * Bugfixes and minor changes:
  - Fixed zero-padding for x and X string format conversion
    specifiers
- update to 0.7.1
  * Bugfixes and minor changes:
  - OS X: Work around a nasty bug in XCode where programs
    explicitly compiled for older versions of OS X were silently
    pulling in features exclusive to the new version, resulting
    in crashes at runtime
  - MSW: Fix detection of thread creation failures
* Sun Oct  2 2016 ecsos@opensuse.org
- update to 0.7.0
  * New features:
  - Add fz::base64_decode and fz::base64_encode
  - Add fz::strtok string tokenizer
  - Added non-throwing fz::to_integral
  - Implemented + (always sign) and - (left align) flags for
    fz::sprintf
* Fri Jul 29 2016 ecsos@opensuse.org
- update to 0.6.1
  * Bugfixes and minor changes:
  - Fix UTF-8 conversion functions and added a testcase
- update to 0.6.0
  * New features:
  - Add fz::sprintf, a safe replacement for for the C sprintf
    function
* Tue Jun 28 2016 ecsos@opensuse.org
- update to 0.5.3
  * New features:
  - Add fz::replace_substrincs to search and replace substrings
    in std::(w)string
  * Bugfixes and minor changes:
  - Explicitly request large file support on 32bit systems
* Sat May 28 2016 ecsos@opensuse.org
- update to 0.5.2
  * New features:
  - Add fz::shared_optional::is_same that checks whether
    two instances share the same underlying pointer value, like
    a shallow equal.
  - Add fz::int_to_hex_char as reverse to fz::hex_char_to_int
* Tue May 10 2016 ecsos@opensuse.org
- Update to version 0.5.1
  - Add constructore to sparse_optional taking pointers
  - Fix compilation on systems where iconv's second argument is
    const
* Wed Apr 27 2016 joerg.lorenzen@ki.tng.de
- Update to version 0.5.0
  - Handle timestamps where midnight is represented as 24:00:00.000
    of the previous day.
  - Fix inverted return value of fz::datetime::empty().
  - Increase performance of event loop if not using timers.
  - Better compatibility with runtimes that change the src pointer
    passed to mbsrtowcs or wcsrtombs.
* Fri Mar 11 2016 davejplater@gmail.com
- Added libfilezilla-date-time.patch.
* Sun Feb 28 2016 ecsos@opensuse.org
- update to 0.4.0.1
- Upstream changes:
  0.4.0.1 (2016-02-22)
  Fix compile error in testcase
  0.4.0 (2016-02-21)
  Added shared_optional and sparse_optional classes
  For more details see svn log:
  https://svn.filezilla-project.org/svn/libfilezilla
* Sun Feb 14 2016 davejplater@gmail.com
- Initial package created from PCLinuxOS src rpm
- Needed for filezilla to build.
